@@ -9,8 +9,6 @@ package Devel::NYTProf::Run;
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Util.pm 809 2009-07-07 13:24:31Z tim.bunce $
-###########################################################
 
 =head1 NAME
 
@@ -61,7 +59,7 @@ sub perl_command_words {
 
 # croaks on failure to execute
 # carps, not croak, if process has non-zero exit status
-# Devel::NYTProf::Data->new may croak, e.g., if data trucated
+# Devel::NYTProf::Data->new may croak, e.g., if data truncated
 sub profile_this {
     my %opt = @_;
 
@@ -78,14 +76,16 @@ sub profile_this {
 
     if (my $src_file = $opt{src_file}) {
         system(@perl, $src_file) == 0
-            or carp "@perl $src_file exited with an error status";
+            or carp "Exit status $? from @perl $src_file";
     }
     elsif (my $src_code = $opt{src_code}) {
         open my $fh, "| @perl"
             or croak "Can't open pipe to @perl";
         print $fh $src_code;
         close $fh 
-            or carp "@perl exited with an error status";
+            or carp $! ? "Error closing @perl pipe: $!"
+                       : "Exit status $? from @perl";
+
     }
     else {
         croak "Neither src_file or src_code was provided";
@@ -93,7 +93,9 @@ sub profile_this {
 
     # undocumented hack that's handy for testing
     if ($opt{htmlopen}) {
-        warn system("nytprofhtml --open --file='$out_file'");
+        my @nytprofhtml_open = ("perl", "nytprofhtml", "--open", "-file=$out_file");
+        warn "Running @nytprofhtml_open\n";
+        system @nytprofhtml_open;
     }
 
     my $profile = Devel::NYTProf::Data->new( { filename => $out_file } );
